[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[tor-commits] [torbutton/maint-1.9.5] Bug 20414.4: Delay banner 1 more day and fix minor error in code
commit 653028f43e5a753197cb0051c69fcf33813a1eba
Author: Arthur Edelstein <arthuredelstein@xxxxxxxxx>
Date: Fri Nov 11 21:11:08 2016 -0800
Bug 20414.4: Delay banner 1 more day and fix minor error in code
---
src/chrome/content/aboutTor/donation_banner.js | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/src/chrome/content/aboutTor/donation_banner.js b/src/chrome/content/aboutTor/donation_banner.js
index 727d984..0953ed2 100644
--- a/src/chrome/content/aboutTor/donation_banner.js
+++ b/src/chrome/content/aboutTor/donation_banner.js
@@ -59,9 +59,9 @@ let shouldShowBanner = function () {
kDonationPageLocales.indexOf(kBrowserLocaleShort) === -1) {
return false;
}
// Only show banner between 2016 Nov 22 and 2017 Jan 25.
let now = new Date();
- let start = new Date(2016, 10, 22);
+ let start = new Date(2016, 10, 23);
let end = new Date(2017, 0, 26);
let shownCountPref = "extensions.torbutton.donation_banner2016.shown_count";
if (now < start || now > end) {
@@ -175,7 +175,7 @@ let observeAttribute = function (target, attributeName, callback) {
}
});
});
- observer.observe(document.body, { attributes: true });
+ observer.observe(target, { attributes: true });
return () => observer.disconnect();
};
_______________________________________________
@@ -59,9 +59,9 @@ let shouldShowBanner = function () {
return false;
}
- // Only show banner between 2016 Nov 22 and 2017 Jan 25.
+ // Only show banner between 2016 Nov 23 and 2017 Jan 25.
let now = new Date();
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits